library(ggmap)

burma <- get_map(location=c(lon=96, lat=20), maptype='satellite', color='color', zoom=5)
#place.df <- geocode(c('Dharan','Mount Everest'))
#place.df$names <- c('Vijayapur', 'Sagarmātha\n(Mt. Everest)')

burma.map <- ggmap(burma, darken=c(.33, 'white')) + coord_map(xlim=c(92,102), ylim=c(29,10)) + borders(database="world", colour="yellow")
#+ geom_text(data=place.df, aes(x=lon, y=lat, label=names), size=4)
#+ geom_point(data=place.df, aes(x=lon, y=lat))

#burma.map

### Alternative Map Stuff ###

library(ggmap)
library(sp)
library(rgeos)
library(raster)
library(maptools)
library(rgdal)
library(ggthemes)

# get better borders

url <- "http://thematicmapping.org/downloads/TM_WORLD_BORDERS_SIMPL-0.3.zip"
fil <- "tm.zip"
if (!file.exists(fil)) download.file(url, fil)
unzip(fil, exdir="tm")
world_borders <- readOGR("./tm/TM_WORLD_BORDERS_SIMPL-0.3.shp", "TM_WORLD_BORDERS_SIMPL-0.3")

# get the google map first so we know the bounding box

burma <- get_map(location=c(lon=96, lat=20), maptype='satellite', color='color', zoom=5)

# get the bounding box

bb <- as.numeric(attr(burma, "bb"))

# clip the borders to the bounding box

clip_region <- as(extent(bb[2], bb[4], bb[1], bb[3]), "SpatialPolygons")
proj4string(clip_region) <- proj4string(world_borders)
clipped_borders <- fortify(crop(world_borders, clip_region))

# plot the map

burma_map <- ggmap(burma, darken=c(.33, 'white'))
burma_map <- burma_map + geom_map(data=clipped_borders, map=clipped_borders,
                                  aes(x=long, y=lat, map_id=id),
                                  color="yellow", alpha=0)
burma_map <- burma_map + coord_map(xlim=c(92,102), ylim=c(29,10))
burma_map <- burma_map + theme_map()
burma_map

### ALTERNATIVE SECOND OPTION ###

# alternatively use just asia read directly from GeoJSON URL
# NOTE this relies on some of the above code
# GeoJSON Asia extract made with http://geojson-maps.kyd.com.au/
# But you could use any NaturalEarth extract. This is less
# granular than the previous one

just_asia <- readOGR("https://gist.githubusercontent.com/hrbrmstr/94bdd47705d05a50f9cf/raw/0ccc6b926e1aa64448e239ac024f04e518d63954/asia.geojson","OGRGeoJSON")

clipped_borders_ja <- crop(just_asia, clip_region)
clipped_borders_ja <- fortify(clipped_borders_ja)

burma_map <- ggmap(burma, darken=c(.33, 'white'))
burma_map <- burma_map + geom_map(data=clipped_borders_ja, map=clipped_borders_ja,
                                  aes(x=long, y=lat, map_id=id),
                                  color="yellow", alpha=0)
burma_map <- burma_map + coord_map(xlim=c(92,102), ylim=c(29,10))
burma_map <- burma_map + theme_map()


burma_map +
  geom_point(aes(x=94.74, y=26.94), color="black", size=10, alpha=0.1, shape=21, fill="blue") + # aho, Ahom, 0
  geom_point(aes(x=92.32, y=26.51), color="blue", size=5, alpha=0.1) + # aio, Aiton, 1.500
  geom_point(aes(x=98.73, y=27.29), color="blue", size=5, alpha=0.1) + # nun, Anong, 450
  geom_point(aes(x=93.73, y=27.19), color="blue", size=5, alpha=0.1) + # apt, Apatani, 28.400
  geom_point(aes(x=92.93, y=22.44), color="blue", size=5, alpha=0.1) + # bgr, Bawm Chin, 15.940
  geom_point(aes(x=99.74, y=22.01), color="blue", size=10, alpha=0.1) + # blr, Blang, 55.200
  geom_point(aes(x=96.10, y=19.75), color="red", size=30, alpha=0.1) + # mya, Burmese, 32.035.300
  geom_point(aes(x=96.99, y=18.98), color="blue", size=5, alpha=0.1) + # bwe, Bwe Karen, 17.200
  geom_point(aes(x=93.79, y=20.73), color="blue", size=5, alpha=0.1) + # dao, Daai Chin, 37.000
  geom_point(aes(x=97.00, y=20.50), color="blue", size=5, alpha=0.1) + # dnu, Danau, 1.000
  geom_point(aes(x=98.20, y=19.89), color="blue", size=5, alpha=0.1) + # eky, Eastern Kaya, 26.000
  geom_point(aes(x=96.95, y=19.50), color="blue", size=5, alpha=0.1) + # kvq, Geba Karen, 40.000
  geom_point(aes(x=101.95, y=22.56), color="blue", size=10, alpha=0.1) + # hnj, Hmong Njua, 312.000
  geom_point(aes(x=97.33, y=25.46), color="blue", size=15, alpha=0.1) + # kac, Jinghpaw, 940.000
  geom_point(aes(x=95.85, y=24.40), color="blue", size=5, alpha=0.1) + # zkd, Kadu, 30.000
  geom_point(aes(x=92.00, y=24.98), color="blue", size=15, alpha=0.1) + # kha, Khasi, 843.000
  geom_point(aes(x=101.67, y=20.25), color="blue", size=15, alpha=0.1) + # kjg, Khmu', 704.000
  geom_point(aes(x=98.55, y=26.10), color="blue", size=5, alpha=0.1) + # lsi, Lacid, 31.800
  geom_point(aes(x=100.21, y=21.27), color="blue", size=15, alpha=0.1) + # lhu, Lahu, 530.350
  geom_point(aes(x=102.13, y=19.88), color="red", size=20, alpha=0.1) + # lao, Lao, 3.273.180
  geom_point(aes(x=94.02, y=22.55), color="blue", size=15, alpha=0.1) + # lis, Lisu, 942.700
  geom_point(aes(x=94.04, y=26.01), color="blue", size=10, alpha=0.1) + # njh, Lotha, 530.350
  geom_point(aes(x=99.83, y=24.94), color="blue", size=10, alpha=0.1) + # mhx, Maru, 103.500
  geom_point(aes(x=92.62, y=22.61), color="blue", size=15, alpha=0.1) + # lus, Mizo, 687.750
  geom_point(aes(x=101.16, y=18.55), color="blue", size=5, alpha=0.1) + # mra, Mlabri, 154 
  geom_point(aes(x=98.12, y=15.49), color="violet", size=15, alpha=0.2) + # mnw, Mon, 851.000
  geom_point(aes(x=94.95, y=26.43), color="blue", size=10, alpha=0.1) + # nbc, Naga Chang, 62.400
  geom_point(aes(x=95.06, y=26.68), color="blue", size=10, alpha=0.1) + # nbe, Naga Konyak, 250.000
  geom_point(aes(x=95.39, y=27.15), color="blue", size=5, alpha=0.1) + # njb, Naga Nocte, 33.000
  geom_point(aes(x=94.36, y=25.05), color="blue", size=10, alpha=0.1) + # nmf, Naga Tangkhul, 142.000
  geom_point(aes(x=100.21, y=18.86), color="red", size=20, alpha=0.1) + # nod, Northern Thai, 6.029.500
  geom_point(aes(x=98.09, y=21.62), color="blue", size=10, alpha=0.1) + # pce, Palaung (Ruching), 272.000
  geom_point(aes(x=97.32, y=23.64), color="blue", size=10, alpha=0.1) + # rbb, Palaung (Rumai), 140.600
  geom_point(aes(x=97.80, y=23.67), color="blue", size=10, alpha=0.1) + # pll, Palaung (Shwe), 150.000
  geom_point(aes(x=97.92, y=24.21), color="blue", size=5, alpha=0.1) + # bxd, Pela, 400
  geom_point(aes(x=95.81, y=27.82), color="blue", size=5, alpha=0.1) + # phk, Phake, 2.000
  geom_point(aes(x=92.26, y=24.82), color="blue", size=10, alpha=0.1) + # pbv, Pnar, 247.000
  geom_point(aes(x=98.00, y=22.00), color="violet", size=20, alpha=0.2) + # shn, Shan, 3.295.000
  geom_point(aes(x=97.71, y=17.99), color="blue", size=20, alpha=0.1) + # ksw, Sgaw Karen, 1.480.000
  geom_point(aes(x=101.28, y=21.03), color="red", size=15, alpha=0.1) + # khb, Tai Lü, 550.960  
  geom_point(aes(x=99.72, y=21.78), color="blue", size=15, alpha=0.1) + # tdd, Tai Nüa, 717.400
  geom_point(aes(x=100.67, y=14.19), color="red", size=30, alpha=0.1) + # tha, Thai, 20.396.930
  geom_point(aes(x=95.61, y=27.30), color="blue", size=5, alpha=0.1) + # sgp, Turung Singpho, 2.500
  geom_point(aes(x=99.38, y=22.87), color="blue", size=15, alpha=0.1) + # prk, Wa, 805.700
  geom_point(aes(x=98.36, y=24.17), color="blue", size=10, alpha=0.1) # atb, Zaiwa, 110.000

  
